@@ -3,8 +3,10 @@
 #
 # USAGE:
 # runAllTests.sh [options]
+#  -J Include job tests in lib/pkp.
 #  -C Include class tests in lib/pkp.
 #  -P Include plugin tests in lib/pkp.
+#  -j Include job tests in application.
 #  -c Include class tests in application.
 #  -p Include plugin tests in application.
 #  -d Display debug output from phpunit.
@@ -35,20 +37,28 @@ DO_ALL=1
 # Various types of tests
 DO_PKP_CLASSES=0
 DO_PKP_PLUGINS=0
+DO_PKP_JOBS=0
 DO_APP_CLASSES=0
 DO_APP_PLUGINS=0
+DO_APP_JOBS=0
 DO_COVERAGE=0
 DEBUG=""
 
 # Parse arguments
-while getopts "CPcpdR" opt; do
+while getopts "CPcpdRJj" opt; do
 	case "$opt" in
+		J)	DO_ALL=0
+			DO_PKP_JOBS=1
+			;;
 		C)	DO_ALL=0
 			DO_PKP_CLASSES=1
 			;;
 		P)	DO_ALL=0
 			DO_PKP_PLUGINS=1
 			;;
+		j)	DO_ALL=0
+			DO_APP_JOBS=1
+			;;
 		c)	DO_ALL=0
 			DO_APP_CLASSES=1
 			;;
@@ -66,6 +76,10 @@ PHPUNIT='php lib/pkp/lib/vendor/phpunit/phpunit/phpunit --configuration lib/pkp/
 # Where to look for tests
 TEST_SUITES='--testsuite '
 
+if [ \( "$DO_ALL" -eq 1 \) -o \( "$DO_PKP_JOBS" -eq 1 \) ]; then
+	TEST_SUITES="${TEST_SUITES}LibraryJobs,"
+fi
+
 if [ \( "$DO_ALL" -eq 1 \) -o \( "$DO_PKP_CLASSES" -eq 1 \) ]; then
 	TEST_SUITES="${TEST_SUITES}LibraryClasses,"
 fi
@@ -74,6 +88,9 @@ if [ \( "$DO_ALL" -eq 1 \) -o \( "$DO_PKP_PLUGINS" -eq 1 \) ]; then
 	TEST_SUITES="${TEST_SUITES}LibraryPlugins,"
 fi
 
+if [ \( "$DO_ALL" -eq 1 \) -o \( "$DO_APP_JOBS" -eq 1 \) ]; then
+	TEST_SUITES="${TEST_SUITES}ApplicationJobs,"
+fi
 if [ \( "$DO_ALL" -eq 1 \) -o \( "$DO_APP_CLASSES" -eq 1 \) ]; then
 	TEST_SUITES="${TEST_SUITES}ApplicationClasses,"
 fi
